/***************************************************************************
                          rbuttongroup.cpp  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/


/****************************************************************************
** rbuttongroup.cpp 1998/09/19 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#include <qbuttongroup.h>
#include <qfiledialog.h>

#include "rbuttongroup.h"
  
#include "rappwin.h"
#include "rfilebase.h"
#include "rfile.h"
#include "rconfig.h"


// Constructor:
//
RButtonGroup::RButtonGroup(QWidget* _parent,
                           const char* _name)
:QButtonGroup(_parent, _name)
{
  setFont( RCONFIG->getFont(0) );
}



// Constructor:
//
RButtonGroup::RButtonGroup(const QString& _title,
                           QWidget* _parent,
                           const char* _name)
:QButtonGroup(_title, _parent, _name)
{
  setFont( RCONFIG->getFont(0) );
}



// Destructor:
//
RButtonGroup::~RButtonGroup()
{
}


// EOF

